@@ -1,79 +1,93 @@
 import os
-from lutris.util.log import logger
-from lutris.util import display, system
-from lutris.util.strings import split_arguments
+from gettext import gettext as _
+
 from lutris.runners.runner import Runner
+from lutris.util import display, system
+from lutris.util.linux import LINUX_SYSTEM
+from lutris.util.log import logger
+from lutris.util.strings import split_arguments
 
 
 class zdoom(Runner):
     # http://zdoom.org/wiki/Command_line_parameters
-    description = "ZDoom DOOM Game Engine"
-    human_name = "ZDoom"
-    platforms = ["Linux"]
+    description = _("ZDoom DOOM Game Engine")
+    human_name = _("ZDoom")
+    platforms = [_("Linux")]
     runner_executable = "zdoom/zdoom"
     game_options = [
         {
             "option": "main_file",
             "type": "file",
-            "label": "WAD file",
-            "help": "The game data, commonly called a WAD file.",
+            "label": _("WAD file"),
+            "help": _("The game data, commonly called a WAD file."),
         },
         {
             "option": "args",
             "type": "string",
-            "label": "Arguments",
-            "help": "Command line arguments used when launching the game.",
+            "label": _("Arguments"),
+            "help": _("Command line arguments used when launching the game."),
         },
         {
             "option": "files",
             "type": "multiple",
-            "label": "PWAD files",
-            "help": (
-                "Used to load one or more PWAD files which generally contain "
-                "user-created levels."
-            ),
+            "label": _("PWAD files"),
+            "help": _("Used to load one or more PWAD files which generally contain "
+                      "user-created levels."),
         },
         {
             "option": "warp",
             "type": "string",
-            "label": "Warp to map",
-            "help": "Starts the game on the given map.",
+            "label": _("Warp to map"),
+            "help": _("Starts the game on the given map."),
         },
         {
             "option": "savedir",
             "type": "directory_chooser",
-            "label": "Save path",
-            "help": ("User-specified path where save files should be located."),
+            "label": _("Save path"),
+            "help": _("User-specified path where save files should be located."),
         },
     ]
     runner_options = [
-        {"option": "2", "label": "Pixel Doubling", "type": "bool", "default": False},
-        {"option": "4", "label": "Pixel Quadrupling", "type": "bool", "default": False},
+        {
+            "option": "2",
+            "label": _("Pixel Doubling"),
+            "type": "bool",
+            "default": False
+        },
+        {
+            "option": "4",
+            "label": _("Pixel Quadrupling"),
+            "type": "bool",
+            "default": False
+        },
         {
             "option": "nostartup",
-            "label": "Disable Startup Screens",
+            "label": _("Disable Startup Screens"),
             "type": "bool",
             "default": False,
         },
         {
             "option": "skill",
-            "label": "Skill",
+            "label": _("Skill"),
             "type": "choice",
             "default": "",
             "choices": {
-                ("None", ""),
-                ("I'm Too Young To Die (1)", "1"),
-                ("Hey, Not Too Rough (2)", "2"),
-                ("Hurt Me Plenty (3)", "3"),
-                ("Ultra-Violence (4)", "4"),
-                ("Nightmare! (5)", "5"),
+                (_("None"), ""),
+                (_("I'm Too Young To Die (1)"), "1"),
+                (_("Hey, Not Too Rough (2)"), "2"),
+                (_("Hurt Me Plenty (3)"), "3"),
+                (_("Ultra-Violence (4)"), "4"),
+                (_("Nightmare! (5)"), "5"),
             },
         },
         {
-            "option": "config",
-            "label": "Config file",
-            "type": "file",
-            "help": (
+            "option":
+            "config",
+            "label":
+            _("Config file"),
+            "type":
+            "file",
+            "help": _(
                 "Used to load a user-created configuration file. If specified, "
                 "the file must contain the wad directory list or launch will fail."
             ),
@@ -81,7 +95,7 @@ class zdoom(Runner):
     ]
 
     def get_executable(self):
-        executable = super(zdoom, self).get_executable()
+        executable = super().get_executable()
         executable_dir = os.path.dirname(executable)
         if not system.path_exists(executable_dir):
             return executable
@@ -92,11 +106,19 @@ class zdoom(Runner):
         return executable
 
     def prelaunch(self):
-        if not system.LINUX_SYSTEM.get_soundfonts():
+        if not LINUX_SYSTEM.get_soundfonts():
             logger.warning("FluidSynth is not installed, you might not have any music")
-        return True
 
-    def play(self):
+    @property
+    def working_dir(self):
+        wad = self.game_config.get("main_file")
+        if wad:
+            return os.path.dirname(os.path.expanduser(wad))
+        wad_files = self.game_config.get("files")
+        if wad_files:
+            return os.path.dirname(os.path.expanduser(wad_files[0]))
+
+    def play(self):  # noqa: C901
         command = [self.get_executable()]
 
         resolution = self.runner_config.get("resolution")
@@ -149,9 +171,7 @@ class zdoom(Runner):
 
         # Append the pwad files to load, if provided.
         files = self.game_config.get("files") or []
-        pwads = [
-            f for f in files if f.lower().endswith(".wad") or f.lower().endswith(".pk3")
-        ]
+        pwads = [f for f in files if f.lower().endswith(".wad") or f.lower().endswith(".pk3")]
         deh = [f for f in files if f.lower().endswith(".deh")]
         bex = [f for f in files if f.lower().endswith(".bex")]
         if deh:
