@@ -23,6 +23,7 @@ class ServiceMedia:
     small_size = None
     dest_path = None
     file_pattern = NotImplemented
+    file_format = NotImplemented
     api_field = NotImplemented
     url_pattern = "%s"
 
@@ -41,9 +42,12 @@ class ServiceMedia:
         """Whether the icon for the specified slug exists locally"""
         return system.path_exists(self.get_absolute_path(slug))
 
-    def get_pixbuf_for_game(self, slug, is_installed=True):
+    def get_pixbuf_for_game(self, slug, size=None, is_installed=True):
+        if not size:
+            size = self.size
+
         image_abspath = self.get_absolute_path(slug)
-        return get_pixbuf(image_abspath, self.size, fallback=get_default_icon(self.size), is_installed=is_installed)
+        return get_pixbuf(image_abspath, size, fallback=get_default_icon(size), is_installed=is_installed)
 
     def get_media_url(self, details):
         if self.api_field not in details:
@@ -87,5 +91,19 @@ class ServiceMedia:
         except HTTPError as ex:
             logger.error("Failed to download %s: %s", url, ex)
 
+    @property
+    def custom_media_storage_size(self):
+        """The size this media is stored in when customized; we accept
+        whatever we get when we download the media, however."""
+        return self.size
+
+    @property
+    def config_ui_size(self):
+        """The size this media should be shown at when in the configuration UI."""
+        return self.size
+
+    def update_desktop(self):
+        """Update the desktop, if this media type appears there. Most don't."""
+
     def render(self):
         """Used if the media requires extra processing"""
