@@ -1,7 +1,14 @@
 """Class to manipulate a process"""
-# Standard Library
 import os
 
+from lutris.util.log import logger
+
+IGNORED_PROCESSES = (
+    "tracker-store",
+    "tracker-extract",
+    "kworker",
+)
+
 
 class InvalidPid(Exception):
 
@@ -15,8 +22,9 @@ class Process:
     def __init__(self, pid):
         try:
             self.pid = int(pid)
-        except ValueError:
-            raise InvalidPid("'%s' is not a valid pid" % pid)
+            self.error_cache = []
+        except ValueError as err:
+            raise InvalidPid("'%s' is not a valid pid" % pid) from err
 
     def __repr__(self):
         return "Process {}".format(self.pid)
@@ -24,10 +32,19 @@ class Process:
     def __str__(self):
         return "{} ({}:{})".format(self.name, self.pid, self.state)
 
+    def _read_content(self, file_path):
+        """Return the contents from a file in /proc"""
+        try:
+            with open(file_path, encoding='utf-8') as proc_file:
+                content = proc_file.read()
+        except (ProcessLookupError, FileNotFoundError, PermissionError):
+            return ""
+        return content
+
     def get_stat(self, parsed=True):
         stat_filename = "/proc/{}/stat".format(self.pid)
         try:
-            with open(stat_filename) as stat_file:
+            with open(stat_filename, encoding='utf-8') as stat_file:
                 _stat = stat_file.readline()
         except (ProcessLookupError, FileNotFoundError):
             return None
@@ -50,7 +67,7 @@ class Process:
         """Return pids of child processes opened by thread `tid` of process."""
         children_path = "/proc/{}/task/{}/children".format(self.pid, tid)
         try:
-            with open(children_path) as children_file:
+            with open(children_path, encoding='utf-8') as children_file:
                 children_content = children_file.read()
         except (FileNotFoundError, ProcessLookupError):
             children_content = ""
@@ -80,9 +97,9 @@ class Process:
     def cmdline(self):
         """Return command line used to run the process `pid`."""
         cmdline_path = "/proc/{}/cmdline".format(self.pid)
-        with open(cmdline_path) as cmdline_file:
-            _cmdline = cmdline_file.read().replace("\x00", " ")
-        return _cmdline
+        _cmdline_content = self._read_content(cmdline_path)
+        if _cmdline_content:
+            return _cmdline_content.replace("\x00", " ").replace("\\", "/")
 
     @property
     def cwd(self):
@@ -90,6 +107,21 @@ class Process:
         cwd_path = "/proc/%d/cwd" % int(self.pid)
         return os.readlink(cwd_path)
 
+    @property
+    def environ(self):
+        """Return the process' environment variables"""
+        environ_path = "/proc/{}/environ".format(self.pid)
+        _environ_text = self._read_content(environ_path)
+        if not _environ_text:
+            return {}
+        try:
+            return dict([line.split("=", 1) for line in _environ_text.split("\x00") if line])
+        except ValueError:
+            if environ_path not in self.error_cache:
+                logger.error("Failed to parse environment variables: %s", _environ_text)
+                self.error_cache.append(environ_path)
+            return {}
+
     @property
     def children(self):
         """Return the child processes of this process"""
@@ -104,3 +136,16 @@ class Process:
         for child in self.children:
             yield child
             yield from child.iter_children()
+
+    def wait_for_finish(self):
+        """Waits until the process finishes
+        This only works if self.pid is a child process of Lutris
+        """
+        try:
+            pid, ret_status = os.waitpid(int(self.pid) * -1, 0)
+        except OSError as ex:
+            logger.error("Failed to get exit status for PID %s", self.pid)
+            logger.error(ex)
+            return -1
+        logger.info("PID %s exited with code %s", pid, ret_status)
+        return ret_status
