@@ -1,5 +1,3 @@
-# pylint: disable=missing-docstring
-# Standard Library
 import os
 import re
 import shutil
@@ -7,12 +5,11 @@ import subprocess
 import tempfile
 import xml.etree.ElementTree
 
-# Lutris Modules
 from lutris.util.log import logger
+from lutris.util.system import execute, read_process_output
 
 
 class CabInstaller:
-
     """Extract and install contents of cab files
 
     Based on an implementation by tonix64: https://github.com/tonix64/python-installcab
@@ -45,7 +42,7 @@ class CabInstaller:
 
     @staticmethod
     def get_arch_from_dll(dll_path):
-        if "x86-64" in subprocess.check_output(["file", dll_path]).decode():
+        if "x86-64" in read_process_output(["file", dll_path]):
             return "win64"
         return "win32"
 
@@ -135,7 +132,7 @@ class CabInstaller:
         return (out, arch)
 
     def get_wineprefix_arch(self):
-        with open(os.path.join(self.prefix, "system.reg")) as reg_file:
+        with open(os.path.join(self.prefix, "system.reg"), encoding='utf-8') as reg_file:
             for line in reg_file.readlines():
                 if line.startswith("#arch=win32"):
                     return "win32"
@@ -176,7 +173,7 @@ class CabInstaller:
                 outdata, arch = self.get_registry_from_manifest(file_path)
                 if outdata:
                     out += outdata
-                    with open(os.path.join(self.tmpdir, file_path + ".reg"), "w") as reg_file:
+                    with open(os.path.join(self.tmpdir, file_path + ".reg"), "w", encoding='utf-8') as reg_file:
                         reg_file.write(out)
                     reg_files.append((file_path + ".reg", arch))
             if file_path.endswith(".dll"):
@@ -197,7 +194,7 @@ class CabInstaller:
         Returns:
             list: Files extracted from the cab file
         """
-        subprocess.check_output(["cabextract", "-F", "*%s*" % component, "-d", self.tmpdir, cabfile])
+        execute(["cabextract", "-F", "*%s*" % component, "-d", self.tmpdir, cabfile])
         return [os.path.join(r, file) for r, d, f in os.walk(self.tmpdir) for file in f]
 
     def install(self, cabfile, component):
